StokeD
==============
StokeD solves the Stokesian dynamics (SD) equations for N interacting particles. SD is a generalization of Brownian dynamics (BD) that includes hydrodynamic coupling interactions.

Features
--------------
+ Hydrodynamic coupling interactions can be turned on or off
+ Flexible interface for user-defined particle interactions
+ Several interactions already available: point electrostatics and electrodynamics, screened Coulomb, van der Walls, hard-sphere collisions, gravity
+ Animation module for visualizing trajectories

Installation
--------------
StokeD can be installed with pip
```shell
pip install stoked
```

Usage
--------------

For examples and use cases, see examples folder.

For full documentation, see docs folder.

License
--------------
StokeD is licensed under the terms of the MIT license.
